// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

////////////////////////////////////////////////////////////////////////////////
////////          BEGIN MANIPULATION FOR HOFFMAN CHAPTER 2 DATA          ///////
////////////////////////////////////////////////////////////////////////////////

// Defining global variable for file location to be replaced in code below
// \\Client\ precedes path in Virtual Desktop outside H drive
    cd "C:\Dropbox\22SP_PSQF6243\PSQF6243_Example5"

// Import chapter 2 data in STATA format
   use "STATA_Chapter2.dta", clear // Has converted all variables to lower-case
   
// Center quantitative predictors near their means
   gen age85 = age - 85
   gen grip9 = grip - 9
// Create 2 indicator-dummy-coded binary predictors for 3 dementia groups
   gen demnf=.  // Create 2 new empty variables 
   gen demnc=.
// Replace for demgroup = none   
   replace demnf=0 if demgroup==1
   replace demnc=0 if demgroup==1
// Replace for demgroup = future 
   replace demnf=1 if demgroup==2
   replace demnc=0 if demgroup==2
// Replace for demgroup = current
   replace demnf=0 if demgroup==3
   replace demnc=1 if demgroup==3
// Label all variables
   label variable age85     "age85: Age in Years (0=85)"
   label variable grip9     "grip9: Grip Strength in Pounds (0=9)"
   label variable sexmw     "sexmw: Sex (0=Men, 1=Women)"
   label variable demnf     "demnf: Dementia Contrast for None=0 vs Future=1"
   label variable demnc     "demnc: Dementia Contrast for None=0 vs Current=1"
   label variable cognition "cognition: Cognition Outcome"
   label variable demgroup  "demgroup: Dementia Group 1N 2F 3C"
// Select cases complete on all variables to be used
   egen nmiss=rowmiss(cognition age grip sexmw demgroup)
   drop if nmiss>0

    
////////////////////////////////////////////////////////////////////////////////
////////               BEGIN GENERAL LINEAR MODELS                        //////
////////////////////////////////////////////////////////////////////////////////

// Open external file to save results to
log using Example5_STATA_Output.log, replace


display "STATA Combined Main-Effects-Only Model Predicting Cognition"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc, level(95)
// TEST lumps together fixed effects for joint tests -- indicate DFnum by ()  
test (c.demnf=0)(c.demnc=0)   // DFnum=2 Omnibus F-test for Demgroup   
// LINCOM creates a single linear combination of fixed effects
lincom c.demnf*-1 + c.demnc*1 // Future vs. Current Diff = B5-B4
// Pred cognition outcomes holding sexMW=men, demNF=none, and demNC=none
// The LONGER WAY –- writing out separate LINCOM statements per prediction
lincom _cons*1 + c.age85*-5 + c.grip9*-3 + c.sexmw*0 + c.demnf*0 + c.demnc*0 // yhat for Age=80 Grip=6
lincom _cons*1 + c.age85*-5 + c.grip9*0  + c.sexmw*0 + c.demnf*0 + c.demnc*0 // yhat for Age=80 Grip=9
lincom _cons*1 + c.age85*-5 + c.grip9*3  + c.sexmw*0 + c.demnf*0 + c.demnc*0 // yhat for Age=80 Grip=12
lincom _cons*1 + c.age85*0  + c.grip9*-3 + c.sexmw*0 + c.demnf*0 + c.demnc*0 // yhat for Age=85 Grip=6
lincom _cons*1 + c.age85*0  + c.grip9*0  + c.sexmw*0 + c.demnf*0 + c.demnc*0 // yhat for Age=85 Grip=9
lincom _cons*1 + c.age85*0  + c.grip9*3  + c.sexmw*0 + c.demnf*0 + c.demnc*0 // yhat for Age=85 Grip=12
lincom _cons*1 + c.age85*5  + c.grip9*-3 + c.sexmw*0 + c.demnf*0 + c.demnc*0 // yhat for Age=90 Grip=6
lincom _cons*1 + c.age85*5  + c.grip9*0  + c.sexmw*0 + c.demnf*0 + c.demnc*0 // yhat for Age=90 Grip=9
lincom _cons*1 + c.age85*5  + c.grip9*3  + c.sexmw*0 + c.demnf*0 + c.demnc*0 // yhat for Age=90 Grip=12
// The SHORTER WAY -- one margins replaces 9 STATA LINCOMs 
// vsquish compresses output empty lines
// predictor=(from(by)to), c.=quantitative predictor 
margins, at(c.age85=(-5(5)5) c.grip9=(-3(3)3) c.sexmw=0 c.demnf=0 c.demnc=0) vsquish
// Get plot of predicted outcomes and save
marginsplot, xdimension(grip9) name(predicted_means, replace)
graph export "STATA Main-Effect-Only GLM Plot.png", replace 

   

display "STATA: GLM adding 2 Interactions -- Sex by Age and Sex by Grip"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc  /// line continuer
                  c.sexmw#c.age85 c.sexmw#c.grip9, level(95)
lincom c.demnf*-1 + c.demnc*1 // Future vs. Current Diff = B5-B4
test (c.demnf=0)(c.demnc=0)   // DFnum=2 F-test for Demgroup
test (c.sexmw#c.age85=0)(c.sexmw#c.grip9=0) // DFnum=2 F-test for new interactions
// Simple slopes of age by sex   
lincom c.age85*1 + c.sexmw#c.age85*0  // Age Slope for Men
lincom c.age85*1 + c.sexmw#c.age85*1  // Age Slope for Women
// Simple slopes of grip by sex   
lincom c.grip9*1 + c.sexmw#c.grip9*0  // Grip Slope for Men
lincom c.grip9*1 + c.sexmw#c.grip9*1  // Grip Slope for Women
// one margins replaces 8 separate LINCOMs; vsquish compresses output empty lines
// Get predicted outcomes for each combination of (from(by)to)
margins, at(c.age85=(-5(10)5) c.grip9=(-3(6)3) c.sexmw=(0(1)1) c.demnf=0 c.demnc=0) vsquish
marginsplot, xdimension(grip9) bydimension(age85)  // Plot pred outcomes by grip 
graph export "STATA Sex by Grip=x GLM Plot.png", replace
marginsplot, xdimension(age85) bydimension(grip9)  // Plot pred outcomes by age 
graph export "STATA Sex by Age=x GLM Plot.png", replace


// Create observed interaction variables to use to get effect sizes
gen sexage85=sexmw*age85
gen sexgrip9=sexmw*grip9
display "STATA semipartial and partial effect sizes per slope"
display "Semipartial versions are not valid for demnf and demnc"
pcorr cognition age85 grip9 sexmw demnf demnc sexage85 sexgrip9

display "STATA Reduced Model to Get SS for DemGroup (as omitted)"
regress cognition c.age85 c.grip9 c.sexmw c.sexmw#c.age85 c.sexmw#c.grip9, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (18529.397-6686.27463)/66296.5382 // sr2 for demnf + demnc = .17863862

display "STATA Reduced Model to Get SS for two sex interactions (omitted)"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (18529.397-18385.9793)/66296.5382 // sr2 for sex*age, sex*grip = .00216328

   
   
display "STATA Eq 2.9: Adding Age by Grip Interaction"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc c.age85#c.grip9, level(95)
lincom c.demnf*-1 + c.demnc*1 // Future vs. Current Diff = B5-B4
test (c.demnf=0)(c.demnc=0)   // DFnum=2 F-test for Demgroup
test (c.age85=0)(c.grip9=0)(c.age85#c.grip9=0) // DFnum=3 F-test for age, grip, age*grip

// dydx in margins provides simple slopes for that variable by (from(by)to) moderator
margins, at(c.grip9=(-3(3)3)) dydx(c.age85) vsquish // Age Slope per Grip
lincom c.age85*1 + c.age85#c.grip9*-3  // Age Slope at Grip =  6
lincom c.age85*1 + c.age85#c.grip9*0   // Age Slope at Grip =  9
lincom c.age85*1 + c.age85#c.grip9*3   // Age Slope at Grip = 12
// dydx in margins provides simple slopes for that variable by (from(by)to) moderator
margins, at(c.age85=(-5(5)5)) dydx(c.grip9) vsquish // Grip Slope per Age
lincom c.grip9*1 + c.age85#c.grip9*-5  // Grip Slope at Age = 80
lincom c.grip9*1 + c.age85#c.grip9*0   // Grip Slope at Age = 85
lincom c.grip9*1 + c.age85#c.grip9*5   // Grip Slope at Age = 90

// Note: to get effect sizes for any lincom slope, run the following immediately after it
//   display "Partial D= "  (2*(r(estimate)/r(se)))/sqrt(r(df))
//   display "Partial R= "     (r(estimate)/r(se))/ sqrt((r(estimate)/r(se))^2+r(df))

// one margins replaces 8 ESTIMATEs in SAS; vsquish compresses output empty lines
// predictor=(from(by)to), c.=quantitative predictor 
margins, at(c.age85=(-5(5)5) c.grip9=(-3(3)3) c.sexmw=0 c.demnf=0 c.demnc=0) vsquish
marginsplot, xdimension(grip9)  // Plot pred outcomes by grip 
graph export "STATA Age by Grip=x GLM Plot.png", replace
marginsplot, xdimension(age85)  // Plot pred outcomes by age 
graph export "STATA Grip by Age=x GLM Plot.png", replace

// Create observed interaction variable to use to get effect sizes
gen age85grip9=age85*grip9
display "STATA semipartial and partial effect sizes per slope"
display "Semipartial versions are not valid for demnf and demnc"
pcorr cognition age85 grip9 sexmw demnf demnc age85grip9

display "STATA Reduced Model to Get SS for demnf and demnc (as omitted)"
regress cognition c.age85 c.grip9 c.sexmw c.age85#c.grip9, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (19185.0411-7437.43517)/66296.5382 // sr2 for demgroup = .17719788

display "STATA Reduced Model to Get SS for age, grip, age*agrip (as omitted)"
regress cognition c.sexmw c.demnf c.demnc, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (19185.0411-15385.1841)/66296.5382 // sr2 for age,grip,age*grip = .05731607


display "STATA Eq 2.9: Age by Grip Interaction adding VCE for Regions"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc c.age85#c.grip9, level(95)
  estat vce  // Aymptotic covariance matrix of fixed effects for regions

   
// Close external file of saved results
log close

